User

Struct User 

pub struct User {
    pub id: UserId,
    pub name: String,
    pub email: String,
}

Fields

id: UserIdname: Stringemail: String

Implementations

Source

impl User

pub fn new(name: impl Into<String>, email: impl Into<String>) -> Self

Creates a new User instance.

Arguments
  • name - User’s display name
  • email - User’s email address
Notes

The id field is initialized as an empty string and will be set by the actor system.